@@ -16,8 +16,5 @@
 --
 module Database.Migrate (module X) where
 
-import Database.Migrate.Data as X
-import Database.Migrate.Kernel as X
-import Database.Migrate.Loader as X
-import Database.Migrate.Main as X
+import Database.Migrate.Migration as X
 import Database.Migrate.PostgreSQL as X
